@@ -135,7 +135,6 @@ class interface(abstract_interface):
         list_valid_devices = self.instrument.list_devices()
         if(len(list_valid_devices)>0):
             list_IDNs_and_devices = [dev[1] + " --> " + dev[0] for dev in list_valid_devices] 
-            #list_IDNs_and_devices = [i for i in list_IDN] 
             self.gui.combo_Devices.addItems(list_IDNs_and_devices)  
         self.logger.info(f"Found {len(list_valid_devices)} devices.") 
 
@@ -156,7 +155,7 @@ class interface(abstract_interface):
             self.start_reading()
         else: #If connection was not successful
             self.logger.error(f"Error: {Msg}")
-            self.gui.set_disconnected_state()
+            self.set_disconnected_state()
 
     def disconnect_device(self):
         self.logger.info(f"Disconnecting from device {self.connected_device_name}...")
@@ -202,9 +201,14 @@ class interface(abstract_interface):
         return True
 
     def set_wavelength(self, wl):
-        if int(self.instrument.wavelength) == int(wl): #in this case the number in the refresh time edit box is the same as the wavelength currently set
-                return True
-        self.logger.info(f"Setting the wavelength to {wl} for the device {self.connected_device_name}...")
+        try:
+            if int(self.instrument.wavelength) == int(wl): #in this case the number in the refresh time edit box is the same as the wavelength currently set
+                    return True
+            self.logger.info(f"Setting the wavelength to {wl} for the device {self.connected_device_name}...")
+        except ValueError:
+            self.logger.error(f"The refresh time must be a valid number.")
+            self.gui.edit_Wavelength.setText(str(self.instrument.wavelength))
+            return False
         try: 
             self.instrument.wavelength = wl
             self.logger.info(f"Wavelength set correctly.")
@@ -274,12 +278,12 @@ class interface(abstract_interface):
 
     def set_zero_powermeter(self):
         try: 
-            (Msg,ID) = self.instrument.set_zero()
+            ID = self.instrument.set_zero()
             self.logger.info(f"Zero-ing the device {self.connected_device_name}...")
             if ID == 1:
                 self.logger.info(f"Device was succesfully zeroed.")
             else:
-                self.logger.error(f"An error occurred while zero-ing this device: {Msg}")
+                self.logger.error(f"An error occurred while zero-ing this device.")
         except Exception as e:
             self.logger.error(f"An error occurred while zero-ing this device: {e}")
         return
